Learn R Programming

readBrukerFlexData (version 1.8.2)

.tof2mass: Calculates mass from time-of-flight values.

Description

This function calculates mass from time of flight values based on the following article: Titulaer, M. K. and Siccama, I. and Dekker, J. L. and van Rijswijk, A. L. and Heeren R. M. and Sillevis Smitt, P. A. and Luider, T. M. (2006) “A database application for pre-processing, storage and comparison of mass spectra derived from patients and controls”, BMC Bioinformatics, 7: 403 http://www.ncbi.nlm.nih.gov/pubmed/16953879

Usage

.tof2mass(tof, c1, c2, c3)

Arguments

tof
double, vector with times-of-flight
c1
metaData$calibrationConstants[1]
c2
metaData$calibrationConstants[2]
c3
metaData$calibrationConstants[3]

Value

double, calculated mass

Details

Arguments are imported from metadata (acqu-file).

References

Titulaer, M. K. and Siccama, I. and Dekker, J. L. and van Rijswijk, A. L. and Heeren R. M. and Sillevis Smitt, P. A. and Luider, T. M. (2006) “A database application for pre-processing, storage and comparison of mass spectra derived from patients and controls”, BMC Bioinformatics, 7: 403 http://www.ncbi.nlm.nih.gov/pubmed/16953879